@@ -50,7 +50,7 @@ open_window (void)
   gtk_container_add (GTK_CONTAINER (window), top);
 
   g_signal_connect (G_OBJECT (window), "delete-event",
-		    G_CALLBACK (g_main_loop_quit), NULL);
+		    G_CALLBACK (gtk_main_quit), NULL);
 
   gtk_window_set_default_size (GTK_WINDOW (window), 240, 320);
   gtk_window_set_title (GTK_WINDOW (window), _("To-do list"));
